import 'dart:async';
import 'dart:convert';

class TsvValue {
  final List<String> columns;

  TsvValue(this.columns);
}

class TsvStreamTransformer extends StreamTransformerBase<String, TsvValue> {
  @override
  Stream<TsvValue> bind(Stream<String> stream) {
    return stream
        .transform(StreamTransformer.fromHandlers(handleData: (line, sink) {
      sink.add(TsvValue(line.split('\t').toList()));
    }));
  }
}

class TsvStreamReader {
  Future<Map<int, String>> read(Stream<String> stream) {
    return stream
        .transform(LineSplitter())
        .transform(TsvStreamTransformer())
        .skip(1)
        .fold<Map<int, String>>(<int, String>{}, (previousValue, element) {
      previousValue[int.parse(element.columns[0])] = element.columns[1];
      return previousValue;
    });
  }
}
